==> viha-5.15.tar.gz: viha-5.15/tavara-takt-1.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "tavara";
$file = basename(__FILE__);

include "common.php";

echo "
<html>
<head>
 <title>VIHA - Tavara</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", tavaran tietojen pivitys</h1>
";

taktiset_linkit();

function kutsut ($current_tavara_id, $current_kutsu_id)
{
  global $prefix;
  
  $sql1 = "
SELECT id,kutsu
FROM ryhma
WHERE id != $current_kutsu_id 
      AND (alue_id = 2
           OR (alue_id = " . s("alue") . " AND paivystys_id = 2)
           OR (paivystys_id = " . s("paivystys") . "))
ORDER BY pri
";
  $result1 = my_mysql_query ($sql1);
  while ($b = mysql_fetch_array($result1)) {
    echo "<a href=\"$file?id=$current_tavara_id&ryhma_id=$b[id]\">"
      . "$b[kutsu]</a> ";
  }
}

$id = get_nro('id');
$ryhma_id = get_nro('ryhma_id');

oltava_sallittu($file, $table, $id);

if (($ryhma_id != '') && saa_tehda("$file:ryhma_id")) {
  $now = date('Y-m-d H:i:s');
  $sql = "
UPDATE tavara
SET paivystys_id=" . s("paivystys") . ", ryhma_id=$ryhma_id, ts='$now'
WHERE id=$id
";
  $result = my_mysql_query ($sql);
  print "<p>Tiedot pivitetty.\n";
  loki($sql);
  taktinen_loki("Tavara " . tavara_tunniste($id)
		. " on nyt ryhmll "
		. ota_kutsu($ryhma_id));
}

print "<form action=\"\" method=\"GET\">\n";

$sql =
  "SELECT tavara, tunniste, ryhma_id, jarjesto_id
   FROM tavara
   WHERE id = $id";
$result = my_mysql_query($sql);
$a = mysql_fetch_array($result);
$tavara = $a['tavara'];
$tunniste = $a['tunniste'];
$ryhma_id = $a['ryhma_id'];
$kutsu = ota_kutsu($ryhma_id);
$jarjesto = jarjesto_personal($a['jarjesto_id']);

echo "<table border=0>\n";
echo "<tr><td><td>Tavara:<td>$tavara ($tunniste)\n";
echo "<tr><td><td>Jrjest:<td>$jarjesto\n";
echo tr_bgcolor() . "<th><th>Nykyinen<th>Pivitysvaihtoehdot";
echo "<tr><td>Ryhm:<td" . bgcolor_vaalsin() . ">$kutsu<td>";
kutsut ($id, $ryhma_id);

print "</table>\n";

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: tavara-takt-1.php,v 1.7 2009/04/18 16:06:56 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/tavara-takt-1.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "tavara";
$file = basename(__FILE__);

include "common.php";

echo "
<html>
<head>
 <title>VIHA - Tavara</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", tavaran tietojen pivitys</h1>
";

taktiset_linkit();

function kutsut ($current_tavara_id, $current_kutsu_id)
{
  global $prefix;
  
  $sql1 = "
SELECT id,kutsu
FROM ryhma
WHERE id != $current_kutsu_id 
      AND (alue_id = 2
           OR (alue_id = " . s("alue") . " AND paivystys_id = 2)
           OR (paivystys_id = " . s("paivystys") . "))
ORDER BY pri
";
  $result1 = my_mysql_query ($sql1);
  while ($b = mysql_fetch_array($result1)) {
    echo "<a href=\"$file?id=$current_tavara_id&ryhma_id=$b[id]\">"
      . "$b[kutsu]</a> ";
  }
}

$id = get_nro('id');
$ryhma_id = get_nro('ryhma_id');

oltava_sallittu($file, $table, $id);

if (($ryhma_id != '') && saa_tehda("$file:ryhma_id")) {
  $now = date('Y-m-d H:i:s');
  $sql =
    "UPDATE tavara
     SET paivystys_id=" . s("paivystys") . ", ryhma_id=$ryhma_id, ts='$now'
     WHERE id=$id";
  $result = my_mysql_query ($sql,true,true);
  $msg = "Tavara " . tavara_tunniste($id)
    . " on nyt ryhmll " . ota_kutsu($ryhma_id);
  tehty($msg);
  taktinen_loki($msg);
}

print "<form action=\"\" method=\"GET\">\n";

$sql =
  "SELECT tavara, tunniste, ryhma_id, jarjesto_id
   FROM tavara
   WHERE id = $id";
$result = my_mysql_query($sql);
$a = mysql_fetch_array($result);
$tavara = $a['tavara'];
$tunniste = $a['tunniste'];
$ryhma_id = $a['ryhma_id'];
$kutsu = ota_kutsu($ryhma_id);
$jarjesto = jarjesto_personal($a['jarjesto_id']);

echo "<table border=0>\n";
echo "<tr><td><td>Tavara:<td>$tavara ($tunniste)\n";
echo "<tr><td><td>Jrjest:<td>$jarjesto\n";
echo tr_vaalsin() . "<th><th>Nykyinen<th>Pivitysvaihtoehdot";
echo "<tr><td>Ryhm:<td" . bgcolor_vaalsin() . ">$kutsu<td>";
kutsut ($id, $ryhma_id);

print "</table>\n";

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: tavara-takt-1.php,v 1.10 2009/10/05 11:12:43 riku Exp $ -->
